
# Slot: has distribution




URI: [biolink:has_distribution](https://w3id.org/biolink/vocab/has_distribution)


## Domain and Range

[DatasetVersion](DatasetVersion.md) &#8594;  <sub>0..1</sub> [DatasetDistribution](DatasetDistribution.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [DatasetVersion](DatasetVersion.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | dct:distribution |

